pub trait ApplicationAction:
Clone
+ Debug
+ Eq
+ PartialEq
+ Send {
// Required methods
fn is_edit_sequence(&self, ctx: &EditContext) -> SequenceStatus;
fn is_last_action(&self, ctx: &EditContext) -> SequenceStatus;
fn is_last_selection(&self, ctx: &EditContext) -> SequenceStatus;
fn is_switchable(&self, ctx: &EditContext) -> bool;
}Expand description
Trait for objects that describe application-specific actions.
Implementors of this trait can be used with Action::Application. This can then be used to create additional keybindings and commands on top of the more editing-specific ones provided by this crate.
Required Methods
Sourcefn is_edit_sequence(&self, ctx: &EditContext) -> SequenceStatus
fn is_edit_sequence(&self, ctx: &EditContext) -> SequenceStatus
Allows controlling how application-specific actions are included in RepeatType::EditSequence.
Sourcefn is_last_action(&self, ctx: &EditContext) -> SequenceStatus
fn is_last_action(&self, ctx: &EditContext) -> SequenceStatus
Allows controlling how application-specific actions are included in RepeatType::LastAction.
Sourcefn is_last_selection(&self, ctx: &EditContext) -> SequenceStatus
fn is_last_selection(&self, ctx: &EditContext) -> SequenceStatus
Allows controlling how application-specific actions are included in RepeatType::LastSelection.
Sourcefn is_switchable(&self, ctx: &EditContext) -> bool
fn is_switchable(&self, ctx: &EditContext) -> bool
Allows controlling whether an application-specific action should be retried in
a new buffer when the currently targeted buffer returns a WrongBuffer-style error.
For example, jumping to a mark in a different buffer when the current one doesn’t contain the mark.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".