Module context

Module context 

Editing Context

Overview

This module contains the contexts used by the editing buffer.

Structs

EditContext
Context for editing operations.
EditContextBuilder
Build a new EditContext.

Traits

Resolve
Trait for values that can be converted by the EditContext.