Resolve

Trait Resolve 

pub trait Resolve<T, R> {
    // Required method
    fn resolve(&self, t: &T) -> R;
}
Trait for values that can be converted by the EditContext.

Required Methods

fn resolve(&self, t: &T) -> R

Use contextual information to convert a T into an R.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors