InsertTextAction

Enum InsertTextAction 

#[non_exhaustive]
pub enum InsertTextAction { OpenLine(TargetShape, MoveDir1D, Count), Paste(PasteStyle, Count), Transcribe(String, MoveDir1D, Count), Type(Specifier<Char>, MoveDir1D, Count), }
Actions for inserting text into a buffer.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


OpenLine(TargetShape, MoveDir1D, Count)

Insert a new line shape-wise before or after the current position.

Example: Using action!
use editor_types::prelude::*;
use editor_types::{action, Action, InsertTextAction};

let shape = TargetShape::LineWise;
let count = Count::Contextual;
let act: Action = InsertTextAction::OpenLine(shape, MoveDir1D::Next, count).into();

// All of these are equivalent:
assert_eq!(act, action!("insert open-line -S line -d next -c ctx"));
assert_eq!(act, action!("insert open-line -S line -d next"));


Paste(PasteStyle, Count)

Paste before or after the current cursor position n times.

Example: Using action!
use editor_types::prelude::*;
use editor_types::{action, Action, InsertTextAction};

let count = 5;
let paste: Action = action!("insert paste -s (side -d next) -c {count}");
assert_eq!(paste, InsertTextAction::Paste(PasteStyle::Side(MoveDir1D::Next), Count::Exact(5)).into());


Transcribe(String, MoveDir1D, Count)

Insert the contents of a String on either side of the cursor.

Example: Using action!
use editor_types::prelude::*;
use editor_types::{action, Action, InsertTextAction};

let input: Action = action!(r#"insert transcribe -i "hello" -d next -c 1"#);
assert_eq!(input, InsertTextAction::Transcribe("hello".into(), MoveDir1D::Next, 1.into()).into());


Type(Specifier<Char>, MoveDir1D, Count)

Type a character on either side of the cursor n times.

Example: Using action!
use editor_types::prelude::*;
use editor_types::{action, Action, InsertTextAction};

let c = Specifier::Exact(Char::from('a'));
let dir = MoveDir1D::Previous;
let count = Count::Contextual;
let act: Action = InsertTextAction::Type(c.clone(), dir, count).into();

// All of these are equivalent:
assert_eq!(act, action!("insert type -i (exact \'a\') -d previous -c ctx"));
assert_eq!(act, action!("insert type -i (exact \'a\') -c ctx"));
assert_eq!(act, action!("insert type -i (exact \'a\') -d previous"));
assert_eq!(act, action!("insert type -i (exact \'a\')"));
assert_eq!(act, action!("insert type -i {c}"));