pub enum RangeEndingType {
Absolute(Count),
All,
Current,
Last,
Mark(Specifier<Mark>),
Search(MoveDir1D),
SubPatSearch(MoveDir1D),
Unspecified,
}Expand description
Methods for determining the start and end of a RangeSpec.
Variants
Absolute(Count)
A specific line number.
All
All lines.
Current
The current line.
Last
The last line.
Mark(Specifier<Mark>)
The position of a given Mark.
Search(MoveDir1D)
The line matching a search using the last value of CommandType::Search.
SubPatSearch(MoveDir1D)
Perform a search using the last substitution pattern.
Unspecified
No line was specified.