Register

Enum Register 

#[non_exhaustive]
pub enum Register {
Show 14 variants Unnamed, UnnamedMacro, UnnamedCursorGroup, RecentlyDeleted(usize), SmallDelete, LastInserted, LastCommand(CommandType), LastYanked, Named(char), AltBufName, CurBufName, Blackhole, SelectionPrimary, SelectionClipboard,
}
Locations for temporarily storing text shared between buffers.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Unnamed

The default register.

For example, "" in Vim.



UnnamedMacro

The default macro register.

For example, "@ in Kakoune.



UnnamedCursorGroup

The default cursor group register.

For example, "^ in Kakoune.



RecentlyDeleted(usize)

Recently deleted text.

For example, "[1-9] in Vim.



SmallDelete

Most recently deleted text that was shorted than a line.

For example, "- in Vim.



LastInserted

A register containing the last inserted text.

For example, ". in Vim.



LastCommand(CommandType)

A register containing the last value entered for a CommandType.

For example, ": and "/ in Vim.



LastYanked

A register containing the last copied text.

For eample, "0 in Vim.



Named(char)

A register named by char.

The index of the most recent deletion is 0, the second most recent deletion is 1, and so on.

For example, "[a-zA-Z] in Vim.



AltBufName

A read-only register containing the alternate buffer name.

For example, "# in Vim.



CurBufName

A read-only register containing the current buffer name.

For example, "% in Vim.



Blackhole

A register that discards all content written to it.

For example, "_ in Vim.



SelectionPrimary

A register representing the windowing environment’s most recently selected text.

For example, "* in Vim, or what clicking the mouse’s middle button pastes in X and Wayland.



SelectionClipboard

A register representing the windowing environment’s most recently copied text.

For example, "+ in Vim, or what the keyboard shortcut pastes in X and Wayland.

Implementations

Source

impl Register

pub fn is_cursor_storage(&self) -> bool

Indicates whether a given register is allowed to store cursor groups.