SelectionSplitStyle

Enum SelectionSplitStyle 

#[non_exhaustive]
pub enum SelectionSplitStyle { Anchor, Lines, Regex(MatchAction), }
Different ways to split existing selections into new ones.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Anchor

Split a selection into two TargetShape::CharWise selections, one at the current cursor position, and the other at the anchor.

Example: Using action!
use editor_types::prelude::*;
use editor_types::{action, Action, SelectionAction};

let style = SelectionSplitStyle::Anchor;
let split: Action = action!("selection split -s anchor");
assert_eq!(split, SelectionAction::Split(style, TargetShapeFilter::ALL).into());


Lines

Split a selection at each line boundary it contains.

Example: Using action!
use editor_types::prelude::*;
use editor_types::{action, Action, SelectionAction};

let style = SelectionSplitStyle::Lines;
let split: Action = action!("selection split -s lines");
assert_eq!(split, SelectionAction::Split(style, TargetShapeFilter::ALL).into());


Regex(MatchAction)

Split a selection into TargetShape::CharWise parts based on the regular expression stored in the register for CommandType::Search.

Example: Using action!
use editor_types::prelude::*;
use editor_types::{action, Action, SelectionAction};

let style = SelectionSplitStyle::Regex(MatchAction::Keep);
let split: Action = action!("selection split -s (regex keep)");
assert_eq!(split, SelectionAction::Split(style, TargetShapeFilter::ALL).into());

let style = SelectionSplitStyle::Regex(MatchAction::Drop);
let split: Action = action!("selection split -s (regex drop)");
assert_eq!(split, SelectionAction::Split(style, TargetShapeFilter::ALL).into());