TargetShape

Enum TargetShape 

pub enum TargetShape {
    CharWise,
    LineWise,
    BlockWise,
}
This specifies either the shape of a visual selection, or a forced motion.

Variants



CharWise

A series of characters.

During a selection, the two points indicate the start and end columns.

Example: Using action!
use editor_types::prelude::*;
use editor_types::{action, Action, InsertTextAction};

let shape = TargetShape::CharWise;
let count = Count::Contextual;
let act: Action = InsertTextAction::OpenLine(shape, MoveDir1D::Next, count).into();

// All of these are equivalent:
assert_eq!(act, action!("insert open-line -S charwise -d next"));
assert_eq!(act, action!("insert open-line -S char -d next"));


LineWise

A series of lines.

During a selection, the two points indicate the start and end lines.

Example: Using action!
use editor_types::prelude::*;
use editor_types::{action, Action, InsertTextAction};

let shape = TargetShape::LineWise;
let count = Count::Contextual;
let act: Action = InsertTextAction::OpenLine(shape, MoveDir1D::Next, count).into();

// All of these are equivalent:
assert_eq!(act, action!("insert open-line -S linewise -d next"));
assert_eq!(act, action!("insert open-line -S line -d next"));


BlockWise

A block of characters.

During a selection, the two points indicate opposite corners.

Example: Using action!
use editor_types::prelude::*;
use editor_types::{action, Action, InsertTextAction};

let shape = TargetShape::BlockWise;
let count = Count::Contextual;
let act: Action = InsertTextAction::OpenLine(shape, MoveDir1D::Next, count).into();

// All of these are equivalent:
assert_eq!(act, action!("insert open-line -S blockwise -d next"));
assert_eq!(act, action!("insert open-line -S block -d next"));