WindowTarget

Enum WindowTarget 

pub enum WindowTarget {
    Single(FocusChange),
    AllBut(FocusChange),
    All,
}
This represents what windows are targeted by a window command.

Variants



Single(FocusChange)

Close the window targeted by FocusChange.

Example: Using action!
use editor_types::prelude::*;
use editor_types::{action, Action, WindowAction};

let fc = WindowTarget::Single(FocusChange::Current);
let flags = CloseFlags::NONE;
let act: Action = WindowAction::Close(fc, flags).into();
assert_eq!(act, action!("window close -t (single current) -F none"));


AllBut(FocusChange)

Close all windows except for the one targeted by FocusChange.

Example: Using action!
use editor_types::prelude::*;
use editor_types::{action, Action, WindowAction};

let fc = WindowTarget::AllBut(FocusChange::Current);
let flags = CloseFlags::NONE;
let act: Action = WindowAction::Close(fc, flags).into();
assert_eq!(act, action!("window close -t (all-but current) -F none"));


All

Close all windows.

Example: Using action!
use editor_types::prelude::*;
use editor_types::{action, Action, WindowAction};

let fc = WindowTarget::All;
let flags = CloseFlags::NONE;
let act: Action = WindowAction::Close(fc, flags).into();
assert_eq!(act, action!("window close -t all -F none"));